aboutsummaryrefslogtreecommitdiffstats
path: root/make/config
diff options
context:
space:
mode:
Diffstat (limited to 'make/config')
-rw-r--r--make/config/jogl/egl-CustomCCode.c5
-rw-r--r--make/config/jogl/egl-CustomJavaCode.java12
-rw-r--r--make/config/jogl/egl-common.cfg8
-rw-r--r--make/config/jogl/egl.cfg7
-rw-r--r--make/config/jogl/eglext.cfg17
-rw-r--r--make/config/jogl/gl-common.cfg4
-rw-r--r--make/config/jogl/gl-es1.cfg23
-rw-r--r--make/config/jogl/gl-es3-impl.cfg37
-rw-r--r--make/config/jogl/gl-gl4bc.cfg61
-rw-r--r--make/config/jogl/gl-if-es2.cfg8
-rw-r--r--make/config/jogl/gl-if-es3.cfg16
-rw-r--r--make/config/jogl/gl-if-gl.cfg4
-rw-r--r--make/config/jogl/gl-if-gl2.cfg22
-rw-r--r--make/config/jogl/gl-if-gl2_es1.cfg12
-rw-r--r--make/config/jogl/gl-if-gl2_es2.cfg6
-rw-r--r--make/config/jogl/gl-if-gl2_es3.cfg10
-rw-r--r--make/config/jogl/gl-if-gl2_gl3.cfg12
-rw-r--r--make/config/jogl/gl-if-gl2es3-subset.cfg2
-rw-r--r--make/config/jogl/gl-if-gl2gl3-subset.cfg2
-rw-r--r--make/config/jogl/gl-if-gl3.cfg14
-rw-r--r--make/config/jogl/gl-if-gl3_es3.cfg10
-rw-r--r--make/config/jogl/gl-if-gl3bc.cfg28
-rw-r--r--make/config/jogl/gl-if-gl4.cfg18
-rw-r--r--make/config/jogl/gl-if-gl4_es3.cfg14
-rw-r--r--make/config/jogl/gl-impl-CustomJavaCode-common.java10
-rw-r--r--make/config/jogl/gl-impl-CustomJavaCode-gl4bc.java56
-rw-r--r--make/config/jogl/gl-impl-CustomJavaCode-gles1.java23
-rw-r--r--make/config/jogl/gl-impl-CustomJavaCode-gles3.java22
-rw-r--r--make/config/jogl/glu-CustomJavaCode-base.java18
-rw-r--r--make/config/jogl/glu-base.cfg2
-rw-r--r--make/config/jogl/glu-common.cfg4
-rw-r--r--make/config/jogl/glu-gl2.cfg8
-rw-r--r--make/config/jogl/glu-gl2es1.cfg4
-rw-r--r--make/config/jogl/glx-x11.cfg2
-rw-r--r--make/config/jogl/wgl-win32.cfg2
-rw-r--r--make/config/nativewindow/win32-lib.cfg4
-rw-r--r--make/config/nativewindow/x11-lib.cfg2
37 files changed, 249 insertions, 260 deletions
diff --git a/make/config/jogl/egl-CustomJavaCode.java b/make/config/jogl/egl-CustomJavaCode.java
index 15689b5d8..0c3935691 100644
--- a/make/config/jogl/egl-CustomJavaCode.java
+++ b/make/config/jogl/egl-CustomJavaCode.java
@@ -1,7 +1,8 @@
private static EGLProcAddressTable _table = new EGLProcAddressTable(new GLProcAddressResolver());
- public static void resetProcAddressTable(DynamicLookupHelper lookup) {
+ protected static boolean resetProcAddressTable(DynamicLookupHelper lookup) {
_table.reset(lookup);
+ return 0 != _table._addressof_eglGetDisplay && 0 != _table._addressof_eglInitialize;
}
// There are some #defines in egl.h that GlueGen and PCPP don't currently handle
@@ -12,15 +13,6 @@
public static final int EGL_DONT_CARE = -1;
public static final int EGL_UNKNOWN = -1;
- protected static long eglGetProcAddress(long eglGetProcAddressHandle, java.lang.String procname)
- {
- if (eglGetProcAddressHandle == 0) {
- throw new GLException("Passed null pointer for method \"eglGetProcAddress\"");
- }
- return dispatch_eglGetProcAddress0(procname, eglGetProcAddressHandle);
- }
-
-
/**
* In case of an error on a particualr attribute, the attribute in the attributes-buffer is set to 0.
* <p>
diff --git a/make/config/jogl/egl-common.cfg b/make/config/jogl/egl-common.cfg
index cf5d0b083..b30abf742 100644
--- a/make/config/jogl/egl-common.cfg
+++ b/make/config/jogl/egl-common.cfg
@@ -5,8 +5,8 @@ GLHeader EGL/eglext.h
# Imports needed by all glue code
Import java.util.*
-Import javax.media.opengl.*
-Import javax.media.opengl.fixedfunc.*
+Import com.jogamp.opengl.*
+Import com.jogamp.opengl.fixedfunc.*
Import jogamp.opengl.*
# Treat all of the EGL types as opaque longs
@@ -29,7 +29,9 @@ Opaque long __EGLFuncPtr
# Implement the first argument to eglGetProcAddress as String instead
# of byte[]
-ArgumentIsString eglGetProcAddress 0
+#ArgumentIsString eglGetProcAddress 0
+#Implemented in EGLContext
+Ignore eglGetProcAddress
ReturnsString eglQueryString
# Force all of the methods to be emitted using dynamic linking so we
diff --git a/make/config/jogl/egl.cfg b/make/config/jogl/egl.cfg
index 94b67951d..453987d3e 100644
--- a/make/config/jogl/egl.cfg
+++ b/make/config/jogl/egl.cfg
@@ -3,7 +3,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/egl
-Package jogamp.opengl.egl
+Package com.jogamp.opengl.egl
JavaClass EGL
Style AllStatic
# Shouldn't matter which one of these we pick up
@@ -19,10 +19,13 @@ HierarchicalNativeOutput false
EmitProcAddressTable true
ProcAddressTableClassName EGLProcAddressTable
GetProcAddressTableExpr _table
+AccessControl com.jogamp.opengl.egl.EGLProcAddressTable PACKAGE_PRIVATE
# Implement the first argument to eglGetProcAddress as String instead
# of byte[]
-ArgumentIsString eglGetProcAddress 0
+#ArgumentIsString eglGetProcAddress 0
+#Implemented in EGLContext
+Ignore eglGetProcAddress
ReturnsString eglQueryString
IncludeAs CustomJavaCode EGL egl-CustomJavaCode.java
diff --git a/make/config/jogl/eglext.cfg b/make/config/jogl/eglext.cfg
index 7fccce716..1da9b253d 100644
--- a/make/config/jogl/eglext.cfg
+++ b/make/config/jogl/eglext.cfg
@@ -3,7 +3,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/egl
-Package jogamp.opengl.egl
+Package com.jogamp.opengl.egl
Style InterfaceAndImpl
JavaClass EGLExt
ImplPackage jogamp.opengl.egl
@@ -15,7 +15,7 @@ Include egl-common.cfg
NIOOnly __ALL__
NIODirectOnly __ALL__
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/jogamp/opengl/egl/EGL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/egl/EGL.java
IgnoreExtension EGL_VERSION_1_X
@@ -24,7 +24,11 @@ HierarchicalNativeOutput false
# Use a ProcAddressTable so we dynamically look up the routines
EmitProcAddressTable true
ProcAddressTableClassName EGLExtProcAddressTable
-GetProcAddressTableExpr _context.getEGLExtProcAddressTable()
+GetProcAddressTableExpr _table
+AccessControl jogamp.opengl.egl.EGLExtProcAddressTable PACKAGE_PRIVATE
+
+Import com.jogamp.opengl.egl.EGLExt
+Import com.jogamp.opengl.egl.EGLClientPixmapHI
CustomCCode #include <stdio.h> /* android */
CustomCCode #include <gluegen_stdint.h>
@@ -47,8 +51,9 @@ CustomJavaCode EGLExt public static final long EGL_NO_SYNC_KHR = 0;
CustomJavaCode EGLExt public boolean isFunctionAvailable(String glFunctionName);
CustomJavaCode EGLExt public boolean isExtensionAvailable(String glExtensionName);
-CustomJavaCode EGLExtImpl public EGLExtImpl(EGLContext context) {
+CustomJavaCode EGLExtImpl public EGLExtImpl(EGLContext context, EGLExtProcAddressTable table) {
CustomJavaCode EGLExtImpl this._context = context;
+CustomJavaCode EGLExtImpl this._table = table;
CustomJavaCode EGLExtImpl }
CustomJavaCode EGLExtImpl public boolean isFunctionAvailable(String glFunctionName)
@@ -61,5 +66,7 @@ CustomJavaCode EGLExtImpl {
CustomJavaCode EGLExtImpl return _context.isExtensionAvailable(glExtensionName);
CustomJavaCode EGLExtImpl }
-CustomJavaCode EGLExtImpl private EGLContext _context;
+CustomJavaCode EGLExtImpl private final EGLContext _context;
+CustomJavaCode EGLExtImpl private final EGLExtProcAddressTable _table;
+CustomJavaCode EGLExtImpl final EGLExtProcAddressTable getProcAdressTable() { return _table; }
diff --git a/make/config/jogl/gl-common.cfg b/make/config/jogl/gl-common.cfg
index d5c45314e..9101d36c9 100644
--- a/make/config/jogl/gl-common.cfg
+++ b/make/config/jogl/gl-common.cfg
@@ -23,8 +23,8 @@ GLHeader GL/glext-20130207.h
# Imports needed by all glue code
Import java.util.*
-Import javax.media.opengl.*
-Import javax.media.opengl.fixedfunc.*
+Import com.jogamp.opengl.*
+Import com.jogamp.opengl.fixedfunc.*
Import jogamp.opengl.*
#####################################################################
diff --git a/make/config/jogl/gl-es1.cfg b/make/config/jogl/gl-es1.cfg
index b73b1a731..cc87a879e 100644
--- a/make/config/jogl/gl-es1.cfg
+++ b/make/config/jogl/gl-es1.cfg
@@ -2,16 +2,16 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/es1
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES1.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLMatrixFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLPointerFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLLightingFunc.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES1.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLMatrixFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLPointerFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLLightingFunc.java
# There are a few routines we don't handle yet
Ignore glGetBufferPointervOES
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceAndImpl
JavaClass GLES1
#Extends GLES1 GLBase
@@ -28,7 +28,8 @@ Include gl-common-extensions.cfg
EmitProcAddressTable true
ProcAddressTableClassName GLES1ProcAddressTable
-GetProcAddressTableExpr ((GLES1ProcAddressTable)_context.getGLProcAddressTable())
+GetProcAddressTableExpr _pat
+# GetProcAddressTableExpr ((GLES1ProcAddressTable)_context.getGLProcAddressTable())
# Force all of the methods to be emitted using dynamic linking so we
# don't need to link against any emulation library on the desktop or
@@ -82,8 +83,8 @@ IncludeAs CustomJavaCode GLES1Impl gl-impl-CustomJavaCode-gles1.java
IncludeAs CustomJavaCode GLES1Impl gl-impl-CustomJavaCode-embedded.java
IncludeAs CustomCCode gl-impl-CustomCCode-gles1.c
-Import javax.media.opengl.GLES1
-Import javax.media.opengl.GLES2
-Import javax.media.opengl.GL2
+Import com.jogamp.opengl.GLES1
+Import com.jogamp.opengl.GLES2
+Import com.jogamp.opengl.GL2
Import com.jogamp.common.nio.Buffers
Import com.jogamp.opengl.util.GLBuffers
diff --git a/make/config/jogl/gl-es3-impl.cfg b/make/config/jogl/gl-es3-impl.cfg
index 9682e49af..22acdbdeb 100644
--- a/make/config/jogl/gl-es3-impl.cfg
+++ b/make/config/jogl/gl-es3-impl.cfg
@@ -2,14 +2,14 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/es3
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GLES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL4ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GLES3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GLES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL4ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GLES3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
Style ImplOnly
ImplPackage jogamp.opengl.es3
@@ -32,7 +32,8 @@ ForceExtension GL_ARB_ES3_compatibility
EmitProcAddressTable true
ProcAddressTableClassName GLES3ProcAddressTable
-GetProcAddressTableExpr ((GLES3ProcAddressTable)_context.getGLProcAddressTable())
+GetProcAddressTableExpr _pat
+# GetProcAddressTableExpr ((GLES3ProcAddressTable)_context.getGLProcAddressTable())
# Force all of the methods to be emitted using dynamic linking so we
# don't need to link against any emulation library on the desktop or
@@ -72,15 +73,15 @@ IncludeAs CustomJavaCode GLES3Impl gl-impl-CustomJavaCode-embedded.java
IncludeAs CustomJavaCode GLES3Impl gl-impl-CustomJavaCode-gl2_es2.java
IncludeAs CustomCCode gl-impl-CustomCCode-gles3.c
-Import javax.media.opengl.GLBase
-Import javax.media.opengl.GL
-Import javax.media.opengl.GL2ES2
-Import javax.media.opengl.GL2ES3
-Import javax.media.opengl.GL3ES3
-Import javax.media.opengl.GL4ES3
-Import javax.media.opengl.GLES3
-Import javax.media.opengl.GLArrayData
-Import javax.media.opengl.GLUniformData
+Import com.jogamp.opengl.GLBase
+Import com.jogamp.opengl.GL
+Import com.jogamp.opengl.GL2ES2
+Import com.jogamp.opengl.GL2ES3
+Import com.jogamp.opengl.GL3ES3
+Import com.jogamp.opengl.GL4ES3
+Import com.jogamp.opengl.GLES3
+Import com.jogamp.opengl.GLArrayData
+Import com.jogamp.opengl.GLUniformData
Import com.jogamp.common.nio.Buffers
Import com.jogamp.opengl.util.GLBuffers
Import java.io.PrintStream
diff --git a/make/config/jogl/gl-gl4bc.cfg b/make/config/jogl/gl-gl4bc.cfg
index 6ccbace44..668fc3427 100644
--- a/make/config/jogl/gl-gl4bc.cfg
+++ b/make/config/jogl/gl-gl4bc.cfg
@@ -2,23 +2,23 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl4
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES1.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL4ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2GL3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL4.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3bc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLMatrixFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLPointerFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLLightingFunc.java
-
-Package javax.media.opengl
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES1.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL4ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2GL3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL4.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3bc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLMatrixFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLPointerFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLLightingFunc.java
+
+Package com.jogamp.opengl
Style InterfaceAndImpl
JavaClass GL4bc
#Extends GL4bc GLBase
@@ -116,7 +116,8 @@ LocalProcAddressCallingConvention __ALL__ APIENTRY
EmitProcAddressTable true
ProcAddressTableClassName GL4bcProcAddressTable
-GetProcAddressTableExpr ((GL4bcProcAddressTable)_context.getGLProcAddressTable())
+GetProcAddressTableExpr _pat
+# GetProcAddressTableExpr ((GL4bcProcAddressTable)_context.getGLProcAddressTable())
# Pick up on-line OpenGL javadoc thanks to user cylab on javagaming.org forums
TagNativeBinding true
@@ -162,18 +163,18 @@ IncludeAs CustomJavaCode GL4bcImpl gl-impl-CustomJavaCode-gl2_es2.java
IncludeAs CustomCCode gl-impl-CustomCCode-gl4bc.c
-Import javax.media.opengl.GLES1
-Import javax.media.opengl.GLES2
-Import javax.media.opengl.GL2ES1
-Import javax.media.opengl.GL2ES2
-Import javax.media.opengl.GL2ES3
-Import javax.media.opengl.GL3ES3
-Import javax.media.opengl.GL4ES3
-Import javax.media.opengl.GL2GL3
-Import javax.media.opengl.GL2
-Import javax.media.opengl.GL3
-Import javax.media.opengl.GL3bc
-Import javax.media.opengl.GL4
+Import com.jogamp.opengl.GLES1
+Import com.jogamp.opengl.GLES2
+Import com.jogamp.opengl.GL2ES1
+Import com.jogamp.opengl.GL2ES2
+Import com.jogamp.opengl.GL2ES3
+Import com.jogamp.opengl.GL3ES3
+Import com.jogamp.opengl.GL4ES3
+Import com.jogamp.opengl.GL2GL3
+Import com.jogamp.opengl.GL2
+Import com.jogamp.opengl.GL3
+Import com.jogamp.opengl.GL3bc
+Import com.jogamp.opengl.GL4
Import com.jogamp.common.nio.Buffers
Import com.jogamp.opengl.util.GLBuffers
Import java.io.PrintStream
diff --git a/make/config/jogl/gl-if-es2.cfg b/make/config/jogl/gl-if-es2.cfg
index 052722f40..23e392e9f 100644
--- a/make/config/jogl/gl-if-es2.cfg
+++ b/make/config/jogl/gl-if-es2.cfg
@@ -2,11 +2,11 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/es2
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GLES2
#Extends GLES2 GLBase
diff --git a/make/config/jogl/gl-if-es3.cfg b/make/config/jogl/gl-if-es3.cfg
index 66fd52597..80273e4cf 100644
--- a/make/config/jogl/gl-if-es3.cfg
+++ b/make/config/jogl/gl-if-es3.cfg
@@ -1,15 +1,15 @@
# This .cfg file is used to generate the GL interface.
JavaOutputDir gensrc/classes
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GLES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL4ES3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GLES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL4ES3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GLES3
#Extends GLES3 GLBase
diff --git a/make/config/jogl/gl-if-gl.cfg b/make/config/jogl/gl-if-gl.cfg
index 5c9e4caa2..d552e5a31 100644
--- a/make/config/jogl/gl-if-gl.cfg
+++ b/make/config/jogl/gl-if-gl.cfg
@@ -1,10 +1,10 @@
# This .cfg file is used to generate the GL interface and implementing class.
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL
Extends GL GLBase
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
HierarchicalNativeOutput false
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl2.cfg b/make/config/jogl/gl-if-gl2.cfg
index 0120bd674..85c7cbe15 100644
--- a/make/config/jogl/gl-if-gl2.cfg
+++ b/make/config/jogl/gl-if-gl2.cfg
@@ -2,17 +2,17 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl2
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES1.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2GL3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLMatrixFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLPointerFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLLightingFunc.java
-
-Package javax.media.opengl
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES1.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2GL3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLMatrixFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLPointerFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLLightingFunc.java
+
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2
#Extends GL2 GLBase
diff --git a/make/config/jogl/gl-if-gl2_es1.cfg b/make/config/jogl/gl-if-gl2_es1.cfg
index b533e83c3..1d517b731 100644
--- a/make/config/jogl/gl-if-gl2_es1.cfg
+++ b/make/config/jogl/gl-if-gl2_es1.cfg
@@ -1,5 +1,5 @@
# This .cfg file is used to generate the GL interface and implementing class.
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2ES1
#Extends GL2ES1 GLBase
@@ -8,11 +8,11 @@ Extends GL2ES1 GLMatrixFunc
Extends GL2ES1 GLPointerFunc
Extends GL2ES1 GLLightingFunc
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLMatrixFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLPointerFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLLightingFunc.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLMatrixFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLPointerFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLLightingFunc.java
HierarchicalNativeOutput false
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl2_es2.cfg b/make/config/jogl/gl-if-gl2_es2.cfg
index db5489d06..3c4dbbb64 100644
--- a/make/config/jogl/gl-if-gl2_es2.cfg
+++ b/make/config/jogl/gl-if-gl2_es2.cfg
@@ -2,10 +2,10 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2ES2
#Extends GL2ES2 GLBase
diff --git a/make/config/jogl/gl-if-gl2_es3.cfg b/make/config/jogl/gl-if-gl2_es3.cfg
index 112bc5434..2390652c4 100644
--- a/make/config/jogl/gl-if-gl2_es3.cfg
+++ b/make/config/jogl/gl-if-gl2_es3.cfg
@@ -2,18 +2,18 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2ES3
#Extends GL2ES3 GLBase
#Extends GL2ES3 GL
Extends GL2ES3 GL2ES2
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-ExtendedInterfaceSymbolsOnly ../build-temp/gluegen-set/javax/media/opengl/GL2ES3Subset.java
+ExtendedInterfaceSymbolsOnly ../build-temp/gluegen-set/com/jogamp/opengl/GL2ES3Subset.java
HierarchicalNativeOutput false
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl2_gl3.cfg b/make/config/jogl/gl-if-gl2_gl3.cfg
index 532a670e6..8e88a116e 100644
--- a/make/config/jogl/gl-if-gl2_gl3.cfg
+++ b/make/config/jogl/gl-if-gl2_gl3.cfg
@@ -1,5 +1,5 @@
# This .cfg file is used to generate the GL interface and implementing class.
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2GL3
#Extends GL2GL3 GLBase
@@ -7,12 +7,12 @@ JavaClass GL2GL3
#Extends GL2GL3 GL2ES2
Extends GL2GL3 GL2ES3
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-ExtendedInterfaceSymbolsOnly ../build-temp/gluegen-set/javax/media/opengl/GL2GL3Subset.java
+ExtendedInterfaceSymbolsOnly ../build-temp/gluegen-set/com/jogamp/opengl/GL2GL3Subset.java
HierarchicalNativeOutput false
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl2es3-subset.cfg b/make/config/jogl/gl-if-gl2es3-subset.cfg
index 3e325e065..a7ecdce8d 100644
--- a/make/config/jogl/gl-if-gl2es3-subset.cfg
+++ b/make/config/jogl/gl-if-gl2es3-subset.cfg
@@ -1,7 +1,7 @@
# This .cfg file is used to generate the common GL2 ES3 set
JavaOutputDir ../../build-temp/gluegen-set
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2ES3Subset
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl2gl3-subset.cfg b/make/config/jogl/gl-if-gl2gl3-subset.cfg
index ecb384ca3..1fae977e5 100644
--- a/make/config/jogl/gl-if-gl2gl3-subset.cfg
+++ b/make/config/jogl/gl-if-gl2gl3-subset.cfg
@@ -1,7 +1,7 @@
# This .cfg file is used to generate the common GL2 GL3 set
JavaOutputDir ../../build-temp/gluegen-set
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL2GL3Subset
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl3.cfg b/make/config/jogl/gl-if-gl3.cfg
index d472fbc29..3dbf86918 100644
--- a/make/config/jogl/gl-if-gl3.cfg
+++ b/make/config/jogl/gl-if-gl3.cfg
@@ -2,14 +2,14 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl3
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2GL3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2GL3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL3
#Extends GL3 GLBase
diff --git a/make/config/jogl/gl-if-gl3_es3.cfg b/make/config/jogl/gl-if-gl3_es3.cfg
index a25d9112a..16e194b80 100644
--- a/make/config/jogl/gl-if-gl3_es3.cfg
+++ b/make/config/jogl/gl-if-gl3_es3.cfg
@@ -2,7 +2,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL3ES3
#Extends GL3ES3 GLBase
@@ -10,10 +10,10 @@ JavaClass GL3ES3
#Extends GL3ES3 GL2ES2
Extends GL3ES3 GL2ES3
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
HierarchicalNativeOutput false
Include gl-common.cfg
diff --git a/make/config/jogl/gl-if-gl3bc.cfg b/make/config/jogl/gl-if-gl3bc.cfg
index 5172c726c..7a1a1c7b3 100644
--- a/make/config/jogl/gl-if-gl3bc.cfg
+++ b/make/config/jogl/gl-if-gl3bc.cfg
@@ -2,20 +2,20 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl3
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES1.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2GL3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLMatrixFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLPointerFunc.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/fixedfunc/GLLightingFunc.java
-
-Package javax.media.opengl
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES1.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2GL3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLMatrixFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLPointerFunc.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/fixedfunc/GLLightingFunc.java
+
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL3bc
#Extends GL3bc GLBase
diff --git a/make/config/jogl/gl-if-gl4.cfg b/make/config/jogl/gl-if-gl4.cfg
index 144c10ad2..07645ac26 100644
--- a/make/config/jogl/gl-if-gl4.cfg
+++ b/make/config/jogl/gl-if-gl4.cfg
@@ -2,16 +2,16 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl4
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL4ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2GL3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL4ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2GL3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL4
#Extends GL4 GLBase
diff --git a/make/config/jogl/gl-if-gl4_es3.cfg b/make/config/jogl/gl-if-gl4_es3.cfg
index 6233d530a..556be2b88 100644
--- a/make/config/jogl/gl-if-gl4_es3.cfg
+++ b/make/config/jogl/gl-if-gl4_es3.cfg
@@ -2,7 +2,7 @@
JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl
-Package javax.media.opengl
+Package com.jogamp.opengl
Style InterfaceOnly
JavaClass GL4ES3
#Extends GL4ES3 GLBase
@@ -11,12 +11,12 @@ JavaClass GL4ES3
#Extends GL4ES3 GL2ES3
Extends GL4ES3 GL3ES3
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES2.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL2ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3ES3.java
-ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/javax/media/opengl/GL3.java
-ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/javax/media/opengl/GLBase.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES2.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL2ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3ES3.java
+ExtendedInterfaceSymbolsIgnore ../build-temp/gensrc/classes/com/jogamp/opengl/GL3.java
+ExtendedInterfaceSymbolsIgnore ../src/jogl/classes/com/jogamp/opengl/GLBase.java
HierarchicalNativeOutput false
Include gl-common.cfg
diff --git a/make/config/jogl/gl-impl-CustomJavaCode-common.java b/make/config/jogl/gl-impl-CustomJavaCode-common.java
index a2ca12960..503c125f0 100644
--- a/make/config/jogl/gl-impl-CustomJavaCode-common.java
+++ b/make/config/jogl/gl-impl-CustomJavaCode-common.java
@@ -1,8 +1,10 @@
+ private final GLProfile glProfile;
+ private final GLContextImpl _context;
+
@Override
public GLProfile getGLProfile() {
return this.glProfile;
}
- private final GLProfile glProfile;
@Override
public final int getBoundBuffer(int target) {
@@ -85,10 +87,8 @@
return _context;
}
- private final GLContextImpl _context;
-
/**
- * @see javax.media.opengl.GLContext#setSwapInterval(int)
+ * @see com.jogamp.opengl.GLContext#setSwapInterval(int)
*/
@Override
public final void setSwapInterval(int interval) {
@@ -96,7 +96,7 @@
}
/**
- * @see javax.media.opengl.GLContext#getSwapInterval()
+ * @see com.jogamp.opengl.GLContext#getSwapInterval()
*/
@Override
public final int getSwapInterval() {
diff --git a/make/config/jogl/gl-impl-CustomJavaCode-gl4bc.java b/make/config/jogl/gl-impl-CustomJavaCode-gl4bc.java
index a8b5f8320..8ec1b3205 100644
--- a/make/config/jogl/gl-impl-CustomJavaCode-gl4bc.java
+++ b/make/config/jogl/gl-impl-CustomJavaCode-gl4bc.java
@@ -1,3 +1,5 @@
+private final GL4bcProcAddressTable _pat;
+
// Tracks glBegin/glEnd calls to determine whether it is legal to
// query Vertex Buffer Object state
private boolean inBeginEndPair;
@@ -17,35 +19,21 @@ public void setObjectTracker(GLObjectTracker tracker) {
public GL4bcImpl(GLProfile glp, GLContextImpl context) {
this._context = context;
- if(null != context) {
- this.bufferObjectTracker = context.getBufferObjectTracker();
- this.bufferStateTracker = context.getBufferStateTracker();
- this.glStateTracker = context.getGLStateTracker();
- } else {
- this.bufferObjectTracker = null;
- this.bufferStateTracker = null;
- this.glStateTracker = null;
- }
+ this._pat = (GL4bcProcAddressTable)_context.getGLProcAddressTable();
+ this.bufferObjectTracker = context.getBufferObjectTracker();
+ this.bufferStateTracker = context.getBufferStateTracker();
+ this.glStateTracker = context.getGLStateTracker();
this.glProfile = glp;
}
public final void finalizeInit() {
- if(null != _context) {
- haveARBPixelBufferObject = isExtensionAvailable("GL_ARB_pixel_buffer_object");
- haveEXTPixelBufferObject = isExtensionAvailable("GL_EXT_pixel_buffer_object");
- haveGL15 = isExtensionAvailable("GL_VERSION_1_5");
- haveGL21 = isExtensionAvailable("GL_VERSION_2_1");
- haveARBVertexBufferObject = isExtensionAvailable("GL_ARB_vertex_buffer_object");
- haveARBVertexArrayObject = _context.getGLVersionNumber().compareTo(GLContext.Version300) >= 0 ||
- isExtensionAvailable("GL_ARB_vertex_array_object");
- } else {
- haveARBPixelBufferObject = false;
- haveEXTPixelBufferObject = false;
- haveGL15 = false;
- haveGL21 = false;
- haveARBVertexBufferObject = false;
- haveARBVertexArrayObject = false;
- }
+ haveARBPixelBufferObject = isExtensionAvailable("GL_ARB_pixel_buffer_object");
+ haveEXTPixelBufferObject = isExtensionAvailable("GL_EXT_pixel_buffer_object");
+ haveGL15 = isExtensionAvailable("GL_VERSION_1_5");
+ haveGL21 = isExtensionAvailable("GL_VERSION_2_1");
+ haveARBVertexBufferObject = isExtensionAvailable("GL_ARB_vertex_buffer_object");
+ haveARBVertexArrayObject = _context.getGLVersionNumber().compareTo(GLContext.Version3_0) >= 0 ||
+ isExtensionAvailable("GL_ARB_vertex_array_object");
}
private int[] imageSizeTemp = new int[1];
@@ -482,7 +470,7 @@ public final void glTexCoordPointer(GLArrayData array) {
@Override
public final void glBufferData(int target, long size, Buffer data, int usage) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glBufferData;
+ final long glProcAddress = _pat._addressof_glBufferData;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glBufferData"));
}
@@ -493,7 +481,7 @@ public final void glBufferData(int target, long size, Buffer data, int usage) {
/** FIXME Add for OpenGL 4.4
@Override
public final void glBufferStorage(int target, long size, Buffer data, int flags) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glBufferStorage;
+ final long glProcAddress = _pat._addressof_glBufferStorage;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glBufferStorage"));
}
@@ -516,7 +504,7 @@ private native void dispatch_glBufferStorage(int target, long size, Object data,
@Override
public final void glNamedBufferDataEXT(int buffer, long size, Buffer data, int usage) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glNamedBufferDataEXT;
+ final long glProcAddress = _pat._addressof_glNamedBufferDataEXT;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glNamedBufferDataEXT"));
}
@@ -538,7 +526,7 @@ private native void dispatch_glNamedBufferDataEXT(int buffer, long size, Object
@Override
public boolean glUnmapBuffer(int target) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glUnmapBuffer;
+ final long glProcAddress = _pat._addressof_glUnmapBuffer;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glUnmapBuffer"));
}
@@ -547,7 +535,7 @@ public boolean glUnmapBuffer(int target) {
@Override
public boolean glUnmapNamedBufferEXT(int buffer) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glUnmapNamedBufferEXT;
+ final long glProcAddress = _pat._addressof_glUnmapNamedBufferEXT;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glUnmapNamedBufferEXT"));
}
@@ -563,7 +551,7 @@ private native boolean dispatch_glUnmapNamedBufferEXT(int buffer, long procAddre
@Override
public final GLBufferStorage mapBuffer(final int target, final int access) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapBuffer;
+ final long glProcAddress = _pat._addressof_glMapBuffer;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapBuffer\" not available");
}
@@ -571,7 +559,7 @@ public final GLBufferStorage mapBuffer(final int target, final int access) {
}
@Override
public final GLBufferStorage mapBufferRange(final int target, final long offset, final long length, final int access) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapBufferRange;
+ final long glProcAddress = _pat._addressof_glMapBufferRange;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapBufferRange\" not available");
}
@@ -580,7 +568,7 @@ public final GLBufferStorage mapBufferRange(final int target, final long offset,
@Override
public final GLBufferStorage mapNamedBuffer(final int bufferName, final int access) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapNamedBufferEXT;
+ final long glProcAddress = _pat._addressof_glMapNamedBufferEXT;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapNamedBufferEXT\" not available");
}
@@ -597,7 +585,7 @@ private native long dispatch_glMapNamedBufferEXT(int buffer, int access, long gl
@Override
public final GLBufferStorage mapNamedBufferRange(final int bufferName, final long offset, final long length, final int access) {
- final long glProcAddress = ((GL4bcProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapNamedBufferRangeEXT;
+ final long glProcAddress = _pat._addressof_glMapNamedBufferRangeEXT;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapNamedBufferRangeEXT\" not available");
}
diff --git a/make/config/jogl/gl-impl-CustomJavaCode-gles1.java b/make/config/jogl/gl-impl-CustomJavaCode-gles1.java
index 6a7e12ca1..636f20d60 100644
--- a/make/config/jogl/gl-impl-CustomJavaCode-gles1.java
+++ b/make/config/jogl/gl-impl-CustomJavaCode-gles1.java
@@ -1,14 +1,11 @@
+private final GLES1ProcAddressTable _pat;
+
public GLES1Impl(GLProfile glp, GLContextImpl context) {
this._context = context;
- if(null != context) {
- this.bufferObjectTracker = context.getBufferObjectTracker();
- this.bufferStateTracker = context.getBufferStateTracker();
- this.glStateTracker = context.getGLStateTracker();
- } else {
- this.bufferObjectTracker = null;
- this.bufferStateTracker = null;
- this.glStateTracker = null;
- }
+ this._pat = (GLES1ProcAddressTable)_context.getGLProcAddressTable();
+ this.bufferObjectTracker = context.getBufferObjectTracker();
+ this.bufferStateTracker = context.getBufferStateTracker();
+ this.glStateTracker = context.getGLStateTracker();
this.glProfile = glp;
}
@@ -312,7 +309,7 @@ public final void glTexCoordPointer(GLArrayData array) {
@Override
public final void glBufferData(int target, long size, Buffer data, int usage) {
- final long glProcAddress = ((GLES1ProcAddressTable)_context.getGLProcAddressTable())._addressof_glBufferData;
+ final long glProcAddress = _pat._addressof_glBufferData;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glBufferData"));
}
@@ -323,7 +320,7 @@ public final void glBufferData(int target, long size, Buffer data, int usage) {
@Override
public boolean glUnmapBuffer(int target) {
- final long glProcAddress = ((GLES1ProcAddressTable)_context.getGLProcAddressTable())._addressof_glUnmapBuffer;
+ final long glProcAddress = _pat._addressof_glUnmapBuffer;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glUnmapBuffer"));
}
@@ -332,7 +329,7 @@ public boolean glUnmapBuffer(int target) {
@Override
public final GLBufferStorage mapBuffer(final int target, final int access) {
- final long glProcAddress = ((GLES1ProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapBuffer;
+ final long glProcAddress = _pat._addressof_glMapBuffer;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapBuffer\" not available");
}
@@ -340,7 +337,7 @@ public final GLBufferStorage mapBuffer(final int target, final int access) {
}
@Override
public final GLBufferStorage mapBufferRange(final int target, final long offset, final long length, final int access) {
- final long glProcAddress = ((GLES1ProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapBufferRange;
+ final long glProcAddress = _pat._addressof_glMapBufferRange;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapBufferRange\" not available");
}
diff --git a/make/config/jogl/gl-impl-CustomJavaCode-gles3.java b/make/config/jogl/gl-impl-CustomJavaCode-gles3.java
index 42adca4b1..a0e3c6570 100644
--- a/make/config/jogl/gl-impl-CustomJavaCode-gles3.java
+++ b/make/config/jogl/gl-impl-CustomJavaCode-gles3.java
@@ -1,15 +1,11 @@
+private final GLES3ProcAddressTable _pat;
public GLES3Impl(GLProfile glp, GLContextImpl context) {
this._context = context;
- if(null != context) {
- this.bufferObjectTracker = context.getBufferObjectTracker();
- this.bufferStateTracker = context.getBufferStateTracker();
- this.glStateTracker = context.getGLStateTracker();
- } else {
- this.bufferObjectTracker = null;
- this.bufferStateTracker = null;
- this.glStateTracker = null;
- }
+ this._pat = (GLES3ProcAddressTable)_context.getGLProcAddressTable();
+ this.bufferObjectTracker = context.getBufferObjectTracker();
+ this.bufferStateTracker = context.getBufferStateTracker();
+ this.glStateTracker = context.getGLStateTracker();
this.glProfile = glp;
this._isES3 = glp.getImplName() == GLProfile.GLES3;
}
@@ -354,7 +350,7 @@ public final void glDepthRange(double zNear, double zFar) {
@Override
public final void glBufferData(int target, long size, Buffer data, int usage) {
- final long glProcAddress = ((GLES3ProcAddressTable)_context.getGLProcAddressTable())._addressof_glBufferData;
+ final long glProcAddress = _pat._addressof_glBufferData;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glBufferData"));
}
@@ -365,7 +361,7 @@ public final void glBufferData(int target, long size, Buffer data, int usage) {
@Override
public boolean glUnmapBuffer(int target) {
- final long glProcAddress = ((GLES3ProcAddressTable)_context.getGLProcAddressTable())._addressof_glUnmapBuffer;
+ final long glProcAddress = _pat._addressof_glUnmapBuffer;
if ( 0 == glProcAddress ) {
throw new GLException(String.format("Method \"%s\" not available", "glUnmapBuffer"));
}
@@ -374,7 +370,7 @@ public boolean glUnmapBuffer(int target) {
@Override
public final GLBufferStorage mapBuffer(final int target, final int access) {
- final long glProcAddress = ((GLES3ProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapBuffer;
+ final long glProcAddress = _pat._addressof_glMapBuffer;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapBuffer\" not available");
}
@@ -382,7 +378,7 @@ public final GLBufferStorage mapBuffer(final int target, final int access) {
}
@Override
public final GLBufferStorage mapBufferRange(final int target, final long offset, final long length, final int access) {
- final long glProcAddress = ((GLES3ProcAddressTable)_context.getGLProcAddressTable())._addressof_glMapBufferRange;
+ final long glProcAddress = _pat._addressof_glMapBufferRange;
if ( 0 == glProcAddress ) {
throw new GLException("Method \"glMapBufferRange\" not available");
}
diff --git a/make/config/jogl/glu-base.cfg b/make/config/jogl/glu-base.cfg
index 05aa2110e..542f8afef 100644
--- a/make/config/jogl/glu-base.cfg
+++ b/make/config/jogl/glu-base.cfg
@@ -4,7 +4,7 @@ JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl
Style ImplOnly
-ImplPackage javax.media.opengl.glu
+ImplPackage com.jogamp.opengl.glu
ImplJavaClass GLU
AccessControl GLU PUBLIC
diff --git a/make/config/jogl/glu-common.cfg b/make/config/jogl/glu-common.cfg
index 85d556b77..45535d21d 100644
--- a/make/config/jogl/glu-common.cfg
+++ b/make/config/jogl/glu-common.cfg
@@ -9,8 +9,8 @@ TagNativeBinding true
#
# Imports needed by all glue code
#
-Import javax.media.opengl.*
-Import javax.media.opengl.glu.*
+Import com.jogamp.opengl.*
+Import com.jogamp.opengl.glu.*
import com.jogamp.opengl.util.glsl.ShaderState
Import jogamp.opengl.*
Import jogamp.opengl.glu.*
diff --git a/make/config/jogl/glu-gl2.cfg b/make/config/jogl/glu-gl2.cfg
index 696e07050..c3a10a900 100644
--- a/make/config/jogl/glu-gl2.cfg
+++ b/make/config/jogl/glu-gl2.cfg
@@ -4,7 +4,7 @@ JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl2
Style ImplOnly
-ImplPackage javax.media.opengl.glu.gl2
+ImplPackage com.jogamp.opengl.glu.gl2
ImplJavaClass GLUgl2
ParentClass GLUgl2 GLU
@@ -24,10 +24,10 @@ CustomCCode #include <inttypes.h>
CustomCCode #endif
EmitProcAddressTable true
-ProcAddressTablePackage javax.media.opengl.glu.gl2
+ProcAddressTablePackage com.jogamp.opengl.glu.gl2
ProcAddressTableClassName GLUgl2ProcAddressTable
GetProcAddressTableExpr getGLUProcAddressTable()
-AccessControl javax.media.opengl.glu.gl2.GLUgl2ProcAddressTable PACKAGE_PRIVATE
+AccessControl com.jogamp.opengl.glu.gl2.GLUgl2ProcAddressTable PACKAGE_PRIVATE
CustomCCode /* Include the OpenGL GLU header */
CustomCCode #include <GL/glu.h>
@@ -45,7 +45,7 @@ Import com.jogamp.gluegen.runtime.opengl.GLProcAddressResolver
Import jogamp.opengl.glu.gl2.nurbs.*
Import jogamp.opengl.glu.mipmap.Mipmap
Import jogamp.opengl.glu.gl2.*
-Import javax.media.opengl.GL2
+Import com.jogamp.opengl.GL2
Import jogamp.opengl.gl2.ProjectDouble
#
diff --git a/make/config/jogl/glu-gl2es1.cfg b/make/config/jogl/glu-gl2es1.cfg
index ef9405fac..98217da1f 100644
--- a/make/config/jogl/glu-gl2es1.cfg
+++ b/make/config/jogl/glu-gl2es1.cfg
@@ -4,7 +4,7 @@ JavaOutputDir gensrc/classes
NativeOutputDir gensrc/native/jogl/gl2es1
Style ImplOnly
-ImplPackage javax.media.opengl.glu.gl2es1
+ImplPackage com.jogamp.opengl.glu.gl2es1
ImplJavaClass GLUgl2es1
ParentClass GLUgl2es1 GLU
@@ -20,7 +20,7 @@ Ignore gluScaleImage
IncludeAs CustomJavaCode GLUgl2es1 glu-CustomJavaCode-gl2es1.java
ManualStaticInitCall GLUgl2es1
-Import javax.media.opengl.GLES1
+Import com.jogamp.opengl.GLES1
Import jogamp.opengl.glu.mipmap.Mipmap
diff --git a/make/config/jogl/glx-x11.cfg b/make/config/jogl/glx-x11.cfg
index 6a5bdc484..38f56c26a 100644
--- a/make/config/jogl/glx-x11.cfg
+++ b/make/config/jogl/glx-x11.cfg
@@ -96,7 +96,7 @@ Ignore GLXHyperpipeConfigSGIX
Ignore GLXPipeRect
Ignore GLXPipeRectLimits
-CustomJavaCode GLX protected static long glXGetProcAddress(long glXGetProcAddressHandle, java.lang.String procname)
+CustomJavaCode GLX static long glXGetProcAddress(long glXGetProcAddressHandle, java.lang.String procname)
CustomJavaCode GLX {
CustomJavaCode GLX if (glXGetProcAddressHandle == 0) {
CustomJavaCode GLX throw new GLException("Passed null pointer for method \"glXGetProcAddress\"");
diff --git a/make/config/jogl/wgl-win32.cfg b/make/config/jogl/wgl-win32.cfg
index d9dbb13e6..435cab0a0 100644
--- a/make/config/jogl/wgl-win32.cfg
+++ b/make/config/jogl/wgl-win32.cfg
@@ -62,7 +62,7 @@ DropUniqVendorExtensions SGIX
DropUniqVendorExtensions SUN
DropUniqVendorExtensions WIN
-CustomJavaCode WGL protected static long wglGetProcAddress(long wglGetProcAddressHandle, java.lang.String procname)
+CustomJavaCode WGL static long wglGetProcAddress(long wglGetProcAddressHandle, java.lang.String procname)
CustomJavaCode WGL {
CustomJavaCode WGL if (wglGetProcAddressHandle == 0) {
CustomJavaCode WGL throw new GLException("Passed null pointer for method \"wglGetProcAddress\"");
diff --git a/make/config/nativewindow/win32-lib.cfg b/make/config/nativewindow/win32-lib.cfg
index 26c744a80..9c60348d2 100644
--- a/make/config/nativewindow/win32-lib.cfg
+++ b/make/config/nativewindow/win32-lib.cfg
@@ -22,8 +22,8 @@ Opaque long HPBUFFERARB
Opaque long HPBUFFEREXT
Opaque long void **
-Import javax.media.nativewindow.util.Point
-Import javax.media.nativewindow.NativeWindowException
+Import com.jogamp.nativewindow.util.Point
+Import com.jogamp.nativewindow.NativeWindowException
Import jogamp.nativewindow.NWJNILibLoader
import jogamp.nativewindow.Debug
diff --git a/make/config/nativewindow/x11-lib.cfg b/make/config/nativewindow/x11-lib.cfg
index ed8c13b54..8104b4697 100644
--- a/make/config/nativewindow/x11-lib.cfg
+++ b/make/config/nativewindow/x11-lib.cfg
@@ -12,7 +12,7 @@ NativeOutputDir gensrc/native/X11
# Imports needed by all glue code
Import java.nio.*
Import java.util.*
-Import javax.media.nativewindow.util.Point
+Import com.jogamp.nativewindow.util.Point
# XID needs to be treated as a long for 32/64 bit compatibility
Opaque long XID
diff --git a/make/config/jogl/egl-CustomCCode.c b/make/config/jogl/egl-CustomCCode.c
index 0163c6742..974bcf9ae 100644
--- a/make/config/jogl/egl-CustomCCode.c
+++ b/make/config/jogl/egl-CustomCCode.c
@@ -4,10 +4,11 @@
#include <EGL/egl.h>
/* Java->C glue code:
* Java package: jogamp.opengl.egl.EGL
* Java method: void eglGetConfigAttributes(long dpy, long config, IntBuffer attributes, IntBuffer values)
*/
-Java_jogamp_opengl_egl_EGL_dispatch_1eglGetConfigAttributes(JNIEnv *env, jclass _unused, jlong dpy, jlong config, jint attributeCount, jobject attributes, jint attributes_byte_offset, jobject values, jint values_byte_offset, jlong procAddress) {
+JNIEXPORT void JNICALL
+Java_com_jogamp_opengl_egl_EGL_dispatch_1eglGetConfigAttributes(JNIEnv *env, jclass _unused, jlong dpy, jlong config, jint attributeCount, jobject attributes, jint attributes_byte_offset, jobject values, jint values_byte_offset, jlong procAddress) {
typedef EGLBoolean (EGLAPIENTRY*_local_PFNEGLGETCONFIGATTRIBPROC)(EGLDisplay dpy, EGLConfig config, EGLint attribute, EGLint * value);
_local_PFNEGLGETCONFIGATTRIBPROC ptr_eglGetConfigAttrib = (_local_PFNEGLGETCONFIGATTRIBPROC) (intptr_t) procAddress;
assert(ptr_eglGetConfigAttrib != NULL);
@@ -4,10 +4,11 @@
#include <EGL/egl.h>
/* Java->C glue code:
- * Java package: jogamp.opengl.egl.EGL
+ * Java package: com.jogamp.opengl.egl.EGL
* Java method: void eglGetConfigAttributes(long dpy, long config, IntBuffer attributes, IntBuffer values)
*/
diff --git a/make/config/jogl/glu-CustomJavaCode-base.java b/make/config/jogl/glu-CustomJavaCode-base.java
index e8047d9d7..c6b892bf6 100644
--- a/make/config/jogl/glu-CustomJavaCode-base.java
+++ b/make/config/jogl/glu-CustomJavaCode-base.java
@@ -84,8 +84,8 @@ static {
Class _gl2es1Class=null;
try {
final ClassLoader cl = GLU.class.getClassLoader();
- _gl2Class = Class.forName("javax.media.opengl.glu.gl2.GLUgl2", false, cl);
- _gl2es1Class = Class.forName("javax.media.opengl.glu.gl2es1.GLUgl2es1", false, cl);
+ _gl2Class = Class.forName("com.jogamp.opengl.glu.gl2.GLUgl2", false, cl);
+ _gl2es1Class = Class.forName("com.jogamp.opengl.glu.gl2es1.GLUgl2es1", false, cl);
} catch (Throwable t) {}
gl2Class = _gl2Class;
gl2es1Class = _gl2es1Class;
@@ -389,7 +389,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
*
* <b>GLU_TESS_BEGIN</b>
* <UL>
* The begin callback is invoked like {@link javax.media.opengl.GL#glBegin
* glBegin} to indicate the start of a (triangle) primitive. The method
* takes a single argument of type int. If the
* <b>GLU_TESS_BOUNDARY_ONLY</b> property is set to <b>GL_FALSE</b>, then
@@ -418,7 +418,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <b>GLU_TESS_EDGE_FLAG</b>
* <UL>
* The edge flag callback is similar to
* {@link javax.media.opengl.GL#glEdgeFlag glEdgeFlag}. The method takes
* a single boolean boundaryEdge that indicates which edges lie on the
* polygon boundary. If the boundaryEdge is <b>GL_TRUE</b>, then each vertex
* that follows begins an edge that lies on the polygon boundary, that is,
@@ -453,7 +453,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <b>GLU_TESS_VERTEX</b>
* <UL>
* The vertex callback is invoked between the begin and end callbacks. It is
* similar to {@link javax.media.opengl.GL#glVertex3f glVertex3f}, and it
* defines the vertices of the triangles created by the tessellation
* process. The method takes a reference as its only argument. This
* reference is identical to the opaque reference provided by the user when
@@ -480,7 +480,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <b>GLU_TESS_END</b>
* <UL>
* The end callback serves the same purpose as
* {@link javax.media.opengl.GL#glEnd glEnd}. It indicates the end of a
* primitive and it takes no arguments. The method prototype for this
* callback is:
* </UL>
@@ -638,9 +638,9 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* @param aCallback
* Specifies the callback object to be called.
*
* @see javax.media.opengl.GL#glBegin glBegin
* @see javax.media.opengl.GL#glEdgeFlag glEdgeFlag
* @see javax.media.opengl.GL#glVertex3f glVertex3f
* @see #gluNewTess gluNewTess
* @see #gluErrorString gluErrorString
* @see #gluTessVertex gluTessVertex
@@ -389,7 +389,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <b>GLU_TESS_BEGIN</b>
* <UL>
- * The begin callback is invoked like {@link javax.media.opengl.GL#glBegin
+ * The begin callback is invoked like {@link com.jogamp.opengl.GL#glBegin
* glBegin} to indicate the start of a (triangle) primitive. The method
* takes a single argument of type int. If the
@@ -418,7 +418,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <UL>
* The edge flag callback is similar to
- * {@link javax.media.opengl.GL#glEdgeFlag glEdgeFlag}. The method takes
+ * {@link com.jogamp.opengl.GL#glEdgeFlag glEdgeFlag}. The method takes
* a single boolean boundaryEdge that indicates which edges lie on the
* polygon boundary. If the boundaryEdge is <b>GL_TRUE</b>, then each vertex
@@ -453,7 +453,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <UL>
* The vertex callback is invoked between the begin and end callbacks. It is
- * similar to {@link javax.media.opengl.GL#glVertex3f glVertex3f}, and it
+ * similar to {@link com.jogamp.opengl.GL#glVertex3f glVertex3f}, and it
* defines the vertices of the triangles created by the tessellation
* process. The method takes a reference as its only argument. This
@@ -480,7 +480,7 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* <UL>
* The end callback serves the same purpose as
- * {@link javax.media.opengl.GL#glEnd glEnd}. It indicates the end of a
+ * {@link com.jogamp.opengl.GL#glEnd glEnd}. It indicates the end of a
* primitive and it takes no arguments. The method prototype for this
* callback is:
@@ -638,9 +638,9 @@ public static final void gluTessNormal(GLUtessellator tessellator, double x, dou
* Specifies the callback object to be called.
*
- * @see javax.media.opengl.GL#glBegin glBegin
- * @see javax.media.opengl.GL#glEdgeFlag glEdgeFlag
- * @see javax.media.opengl.GL#glVertex3f glVertex3f
+ * @see com.jogamp.opengl.GL#glBegin glBegin
+ * @see com.jogamp.opengl.GL#glEdgeFlag glEdgeFlag
+ * @see com.jogamp.opengl.GL#glVertex3f glVertex3f
* @see #gluNewTess gluNewTess
* @see #gluErrorString gluErrorString